import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const _ = require('lodash');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
// 考试端-保安员管理
const security = [
  {
    path: '/baoanexam/security/kcbp',
    meta: { title: '考场编排' },
    component: () => import('../views/baoanexam/security/kcbp/index.vue'),
  },
  {
    path: '/baoanexam/security/kcbp/add',
    meta: { title: '考场编排-添加' },
    component: () => import('../views/baoanexam/security/kcbp/add.vue'),
  },
  {
    path: '/baoanexam/security/zkzdy',
    meta: { title: '准考证打印' },
    component: () => import('../views/baoanexam/security/zkzdy/index.vue'),
  },
  {
    path: '/baoanexam/security/zkzfmdy',
    meta: { title: '准考证封面打印' },
    component: () => import('../views/baoanexam/security/zkzfmdy/index.vue'),
  },
  {
    path: '/baoanexam/security/zkzcx',
    meta: { title: '准考证查询' },
    component: () => import('../views/baoanexam/security/zkzcx/index.vue'),
  },
  {
    path: '/baoanexam/security/ksxxdc',
    meta: { title: '考生信息导出' },
    component: () => import('../views/baoanexam/security/ksxxdc/index.vue'),
  },
  {
    path: '/baoanexam/security/ksqkdj',
    meta: { title: '考试情况登记' },
    component: () => import('../views/baoanexam/security/ksqkdj/index.vue'),
  },
  {
    path: '/baoanexam/security/kscjcx',
    meta: { title: '考试成绩查询' },
    component: () => import('../views/baoanexam/security/kscjcx/index.vue'),
  },
  {
    path: '/baoanexam/security/zkzdyrz',
    meta: { title: '准考证打印日志' },
    component: () => import('../views/baoanexam/security/zkzdyrz/index.vue'),
  },
];
const baoanexam = [
  {
    path: '/exam/questionType',
    meta: { title: '考试题型设置' },
    component: () => import('../views/baoanexam/exam/questionType/index.vue'),
  },
  {
    path: '/exam/config',
    meta: { title: '考试设置' },
    component: () => import('../views/baoanexam/exam/config/index.vue'),
  },
  {
    path: '/exam/question',
    meta: { title: '考试题库' },
    component: () => import('../views/baoanexam/exam/question/index.vue'),
  },
  {
    path: '/exam/exam',
    meta: { title: '试卷管理' },
    component: () => import('../views/baoanexam/exam/exam/index.vue'),
  },
  {
    path: '/exam/answer',
    meta: { title: '考试结果' },
    component: () => import('../views/baoanexam/exam/answer/index.vue'),
  },
];
const web = [
  {
    path: '/',
    redirect: '/adminCenter/homeIndex',
  },
  // 管理登录
  {
    path: '/login',
    name: 'login',
    meta: { title: '管理登录', noCheck: true },
    component: () => import('../views/login.vue'),
  },
  // 管理中心
  {
    path: '/',
    name: 'adminCenter',
    component: () => import('@common/src/components/admin-frame/Home.vue'),
    children: [
      {
        path: '/adminCenter/homeIndex',
        name: 'admin_homeIndex',
        meta: { title: '首页' },
        component: () => import('../views/homeIndex/index.vue'),
      },
      ...baoanexam,
      ...security,
    ],
  },
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  document.title = `${to.meta.title} `;
  const noCheck = _.get(to, 'meta.noCheck', false);
  if (noCheck) next();
  else {
    const token = localStorage.getItem('token');
    if (!token) next('/login');
    else {
      store.commit('setToken', token, { root: true });
      next();
    }
  }
});

export default router;
